@@ -14,15 +14,14 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <https://www.gnu.org/licenses/>.
 
-import os
-import sys
+import os.path
 import datetime
 import hashlib
 import gettext
 from gettext import gettext as _
 import gi
 gi.require_version('Gtk', '3.0')
-from gi.repository import Gtk, Gio
+from gi.repository import Gtk
 gettext.textdomain('gTranscribe')
 
 
@@ -42,7 +41,7 @@ def ns_to_time(ns):
     Converts nanoseconds to a datetime.time object.
 
     :Parameters:
-        - `ns`: Nanoseconds as int.
+        - 'ns': Nanoseconds as int.
 
     :Return:
         - A datetime.time object.
@@ -62,7 +61,7 @@ def time_to_ns(time):
     Converts a datetime.time object to nanoseconds.
 
     :Parameters:
-        - `time`: A datetime.time object.
+        - 'time': A datetime.time object.
 
     :Return:
         - Nanoseconds as int.
@@ -75,27 +74,18 @@ def time_to_ns(time):
     return sum(values)
 
 
-def filepath_to_uri(path):
-    file = Gio.File.new_for_path(path)
-    return file.get_uri()
-
-
-def uri_to_filepath(uri):
-    file = Gio.File.new_for_uri(uri)
-    return file.get_path()
-
-
-def get_open_filename(self):
+def get_open_filename(self, title, filter_name, filter_mime):
+    """Displays a file open dialog and returns the filename."""
     filename = None
-    chooser = Gtk.FileChooserDialog(_("Open File..."), self.window,
+    chooser = Gtk.FileChooserDialog(title, self.window,
                                     Gtk.FileChooserAction.OPEN,
                                     (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
                                      Gtk.STOCK_OPEN, Gtk.ResponseType.OK))
-    filter = Gtk.FileFilter()
-    filter.set_name(_('Plain Text Files'))
-    filter.add_mime_type('text/plain')
-    chooser.add_filter(filter)
-    chooser.set_filter(filter)
+    file_filter = Gtk.FileFilter()
+    file_filter.set_name(filter_name)
+    file_filter.add_mime_type(filter_mime)
+    chooser.add_filter(file_filter)
+    chooser.set_filter(file_filter)
 
     response = chooser.run()
     if response == Gtk.ResponseType.OK:
@@ -105,8 +95,9 @@ def get_open_filename(self):
 
 
 def get_save_filename(self):
+    """Displays a file save dialog and returns the filename."""
     filename = None
-    chooser = Gtk.FileChooserDialog(_("Save File..."), self.window,
+    chooser = Gtk.FileChooserDialog(_("Save Text File"), self.window,
                                     Gtk.FileChooserAction.SAVE,
                                     (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
                                      Gtk.STOCK_SAVE, Gtk.ResponseType.OK))
@@ -118,7 +109,8 @@ def get_save_filename(self):
 
 
 def error_message(self, message):
-    dialog = Gtk.MessageDialog(None,
+    """Displays the string 'message' in an error dialog."""
+    dialog = Gtk.MessageDialog(self.window,
                                Gtk.DialogFlags.MODAL |
                                Gtk.DialogFlags.DESTROY_WITH_PARENT,
                                Gtk.MessageType.ERROR, Gtk.ButtonsType.OK,
@@ -128,6 +120,15 @@ def error_message(self, message):
 
 
 def md5_of_file(fname):
+    """
+    Calculate the md5 hash of the given file
+
+    :Parameters:
+        - 'fname': filename.
+
+    :Return:
+        - A string of length 32, containing the md5 hash as hexadecimal digits.
+    """
     md5 = hashlib.md5()
     f = open(fname, 'rb')
     while True:
@@ -137,3 +138,16 @@ def md5_of_file(fname):
         md5.update(data)
     f.close()
     return md5.hexdigest()
+
+
+def get_data_file(root_dir, *path_segments):
+    """Return the absolute path of the given data file."""
+    # Where to look for data (ui and image files). By default,
+    # this is ../data, relative your trunk layout
+    data_directory = os.path.join(root_dir, 'data/')
+
+    # If this path does not exist fall back to system wide directory
+    if not os.path.exists(data_directory):
+        data_directory = os.path.join(root_dir, 'share/gTranscribe/')
+
+    return os.path.join(data_directory, *path_segments)
